@@ -31,28 +31,15 @@ void
 eel_accessibility_set_up_label_widget_relation (GtkWidget *label, GtkWidget *widget)
 {
 	AtkObject *atk_widget, *atk_label;
-	AtkRelationSet *relation_set;
-	AtkRelation *relation;
-	AtkObject *targets[1];
 
 	atk_label = gtk_widget_get_accessible (label);
 	atk_widget = gtk_widget_get_accessible (widget);
 
 	/* Create the label -> widget relation */
-	relation_set = atk_object_ref_relation_set (atk_label);
-	targets[0] = atk_widget;
-	relation = atk_relation_new (targets, 1, ATK_RELATION_LABEL_FOR);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (relation);
-	g_object_unref (relation_set);
+	atk_object_add_relationship (atk_label, ATK_RELATION_LABEL_FOR, atk_widget);
 
 	/* Create the widget -> label relation */
-	relation_set = atk_object_ref_relation_set (atk_widget);
-	targets[0] = atk_label;
-	relation = atk_relation_new (targets, 1, ATK_RELATION_LABELLED_BY);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (relation);
-	g_object_unref (relation_set);
+	atk_object_add_relationship (atk_label, ATK_RELATION_LABELLED_BY, atk_widget);
 }
 
 /*
@@ -243,6 +230,10 @@ get_simple_text (gpointer object)
 		gobject = eel_accessibility_get_gobject (object);
 	}
 
+	if (!gobject) {
+		return NULL;
+	}
+
 	aif = EEL_ACCESSIBLE_TEXT_GET_IFACE (gobject);
 	if (!aif) {
 		g_warning ("No accessible text inferface on '%s'",
