@@ -18,6 +18,7 @@
    Boston, MA 02111-1307, USA.
 
 */
+#include <config.h>
 
 #include "eel-alert-dialog.h"
 #include "eel-i18n.h"
@@ -341,8 +342,7 @@ eel_alert_dialog_new (GtkWindow     *parent,
                       GtkMessageType type,
                       GtkButtonsType buttons,
                       const gchar   *primary_message,
-                      const gchar   *secondary_message,
-		      const gchar   *title)
+                      const gchar   *secondary_message)
 {
 	GtkWidget *widget;
 	GtkDialog *dialog;
@@ -361,10 +361,12 @@ eel_alert_dialog_new (GtkWindow     *parent,
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_has_separator (dialog, FALSE);
-  
-	gtk_window_set_title (GTK_WINDOW (dialog),
-	                      (title != NULL) ? title : "");
-	
+
+	/* Make sure we don't get a window title. 
+         * HIG says that alert dialogs should not have window title
+         */
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+  	
 	eel_alert_dialog_set_primary_label (EEL_ALERT_DIALOG (dialog),
 	                                    primary_message);
 		       
