@@ -97,6 +97,11 @@ void                        eel_background_set_is_constant_size             (Eel
 char *                      eel_background_get_color                        (EelBackground               *background);
 char *                      eel_background_get_image_uri                    (EelBackground               *background);
 EelBackgroundImagePlacement eel_background_get_image_placement              (EelBackground               *background);
+gboolean                    eel_background_get_suggested_pixmap_size        (EelBackground               *background,
+                                                                             int                          entire_width,
+                                                                             int                          entire_height,
+                                                                             int                         *pixmap_width,
+                                                                             int                         *pixmap_height);
 gboolean                    eel_background_is_dark                          (EelBackground               *background);
 gboolean                    eel_background_is_set                           (EelBackground               *background);
 gboolean                    eel_background_is_loaded                        (EelBackground               *background);
@@ -183,6 +188,12 @@ gboolean                    eel_widget_has_attached_background              (Gtk
 /* Find the background ancestor for the widget. */
 GtkWidget *                 eel_gtk_widget_find_background_ancestor         (GtkWidget                   *widget);
 
+/* Should be TRUE for desktop background */
+void			    eel_background_set_desktop 			    (EelBackground              *background,
+									     GtkWidget *widget, 
+									     gboolean is_desktop);
+gboolean		    eel_background_is_desktop 			    (EelBackground              *background);
+
 typedef struct EelBackgroundDetails EelBackgroundDetails;
 
 struct EelBackground
